@@ -93,7 +93,7 @@ resources to test.  Currently only the following are defined:
                 in the standard library and test suite.  This takes
                 a long time.
 
-    subprocess  Run all tests for the subprocess module. 
+    subprocess  Run all tests for the subprocess module.
 
 To enable all resources except one, use '-uall,-<resource>'.  For
 example, to run all the tests except for the bsddb tests, give the
@@ -1066,6 +1066,34 @@ _expectations = {
         test_winreg
         test_winsound
         """,
+    'aix5':
+        """
+        test_aepack
+        test_al
+        test_applesingle
+        test_bsddb
+        test_bsddb185
+        test_bsddb3
+        test_bz2
+        test_cd
+        test_cl
+        test_dl
+        test_gdbm
+        test_gl
+        test_gzip
+        test_imgfile
+        test_linuxaudiodev
+        test_macfs
+        test_macostools
+        test_nis
+        test_ossaudiodev
+        test_sunaudiodev
+        test_tcl
+        test_winreg
+        test_winsound
+        test_zipimport
+        test_zlib
+        """,
      'openbsd3':
          """
        test_aepack
