@@ -22,13 +22,15 @@ if sys.platform.startswith('atheos'):
 
 if sys.platform in ('netbsd1', 'Darwin1.2', 'darwin',
                     'freebsd2', 'freebsd3', 'freebsd4', 'freebsd5', 'freebsd6',
-                    'bsdos2', 'bsdos3', 'bsdos4'):
-    lockdata = struct.pack('lxxxxlxxxxlhh', 0, 0, 0, fcntl.F_WRLCK, 0)
-elif sys.platform in ['openbsd', 'openbsd2', 'openbsd3']:
-    if sys.maxint == 2147483647:
-        lockdata = struct.pack('lxxxxlxxxxlhh', 0, 0, 0, fcntl.F_WRLCK, 0)
+                    'bsdos2', 'bsdos3', 'bsdos4',
+                    'openbsd', 'openbsd2', 'openbsd3'):
+    if struct.calcsize('l') == 8:
+        off_t = 'l'
+        pid_t = 'i'
     else:
-        lockdata = struct.pack('ixxxxixxxxihh', 0, 0, 0, fcntl.F_WRLCK, 0)
+        off_t = 'lxxxx'
+        pid_t = 'l'
+    lockdata = struct.pack(off_t+off_t+pid_t+'hh', 0, 0, 0, fcntl.F_WRLCK, 0)
 elif sys.platform in ['aix3', 'aix4', 'hp-uxB', 'unixware7']:
     lockdata = struct.pack('hhlllii', fcntl.F_WRLCK, 0, 0, 0, 0, 0, 0)
 elif sys.platform in ['os2emx']:
@@ -43,7 +45,7 @@ if lockdata:
 f = open(filename, 'w')
 rv = fcntl.fcntl(f.fileno(), fcntl.F_SETFL, os.O_NONBLOCK)
 if verbose:
-    print 'Status from fnctl with O_NONBLOCK: ', rv
+    print 'Status from fcntl with O_NONBLOCK: ', rv
 
 if sys.platform not in ['os2emx']:
     rv = fcntl.fcntl(f.fileno(), fcntl.F_SETLKW, lockdata)
